# CorporateWifi


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**corporate_wlan** | **bool** |  | [optional] 
**radius_server** | [**RadiusServer**](RadiusServer.md) |  | [optional] 
**security_auth_type** | **str** |  | [optional] 
**ssid** | **str** |  | [optional] 
**visibility** | **bool** |  | [optional] 
**wpa_psk_key** | **str** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


